@@ -10,10 +10,12 @@
 
 #include <QObject>
 
+#include <memory>
+
 #include <kiocore_export.h>
 
-namespace KIO {
-
+namespace KIO
+{
 class FavIconsCachePrivate;
 
 /**
@@ -26,7 +28,7 @@ class KIOCORE_EXPORT FavIconsCache : public QObject
     Q_OBJECT
 
 public:
-    static FavIconsCache* instance();
+    static FavIconsCache *instance();
 
     // Fast cache lookup, used by KIO::favIconForUrl
     QString iconForUrl(const QUrl &url);
@@ -49,8 +51,8 @@ Q_SIGNALS:
 
 private:
     FavIconsCache();
-    ~FavIconsCache();
-    FavIconsCachePrivate * const d;
+    ~FavIconsCache() override;
+    std::unique_ptr<FavIconsCachePrivate> const d;
 };
 
 }
