@@ -1,32 +1,19 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_JOB_BASE_H
 #define KIO_JOB_BASE_H
 
-#include <kcompositejob.h>
+#include <KCompositeJob>
 #include <kio/metadata.h>
 
 namespace KIO
 {
-
 class JobUiDelegateExtension;
 
 class JobPrivate;
@@ -37,17 +24,20 @@ class JobPrivate;
  * For all jobs created in an application, the code looks like
  *
  * \code
- *   KIO::Job * job = KIO::someoperation( some parameters );
- *   connect( job, SIGNAL( result( KJob * ) ),
- *            this, SLOT( slotResult( KJob * ) ) );
+ *   KIO::Job* job = KIO::someoperation(some parameters);
+ *   connect(job, &KJob::result, this, &MyClass::slotResult);
  * \endcode
  *   (other connects, specific to the job)
  *
  * And slotResult is usually at least:
  *
  * \code
- *  if ( job->error() )
- *      job->uiDelegate()->showErrorMessage();
+ * void MyClass::slotResult(KJob *job)
+ * {
+ *   if (job->error()) {
+ *     job->uiDelegate()->showErrorMessage();
+ *   }
+ * }
  * \endcode
  * @see KIO::Scheduler
  */
@@ -60,18 +50,21 @@ protected:
     Job(JobPrivate &dd);
 
 public:
-    virtual ~Job();
-    void start() override {} // Since KIO autostarts its jobs
+    ~Job() override;
+    void start() override
+    {
+    } // Since KIO autostarts its jobs
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Retrieves the UI delegate of this job.
      *
-     * @deprecated since 5.0, can now be replaced with uiDelegate()
-     *
      * @return the delegate used by the job to communicate with the UI
+     *
+     * @deprecated since 5.0, can now be replaced with uiDelegate()
      */
-#ifndef KIOCORE_NO_DEPRECATED
-    KIOCORE_DEPRECATED KJobUiDelegate *ui() const;
+    KIOCORE_DEPRECATED_VERSION(5, 0, "Use KJob::uiDelegate()")
+    KJobUiDelegate *ui() const;
 #endif
 
     /**
@@ -115,7 +108,7 @@ public:
      *
      * Example for errid == ERR_CANNOT_OPEN_FOR_READING:
      * \code
-     *   i18n( "Could not read\n%1" ).arg( errortext );
+     *   i18n("Could not read\n%1", errortext);
      * \endcode
      * Use this to display the error yourself, but for a dialog box
      * use uiDelegate()->showErrorMessage(). Do not call it if error()
@@ -133,11 +126,10 @@ public:
      * @param reqUrl the request URL that generated this error message
      * @param method the method that generated this error message
      * (unimplemented)
-     * @return the following strings: caption, error + description,
+     * @return the following strings: title, error + description,
      *         causes+solutions
      */
-    QStringList detailedErrorStrings(const QUrl *reqUrl = nullptr,
-                                     int method = -1) const;
+    QStringList detailedErrorStrings(const QUrl *reqUrl = nullptr, int method = -1) const;
 
     /**
      * Set the parent Job.
@@ -158,7 +150,7 @@ public:
     Job *parentJob() const;
 
     /**
-     * Set meta data to be sent to the slave, replacing existing
+     * Set meta data to be sent to the worker, replacing existing
      * meta data.
      * @param metaData the meta data to set
      * @see addMetaData()
@@ -167,7 +159,7 @@ public:
     void setMetaData(const KIO::MetaData &metaData);
 
     /**
-     * Add key/value pair to the meta data that is sent to the slave.
+     * Add key/value pair to the meta data that is sent to the worker.
      * @param key the key of the meta data
      * @param value the value of the meta data
      * @see setMetaData()
@@ -176,7 +168,7 @@ public:
     void addMetaData(const QString &key, const QString &value);
 
     /**
-     * Add key/value pairs to the meta data that is sent to the slave.
+     * Add key/value pairs to the meta data that is sent to the worker.
      * If a certain key already existed, it will be overridden.
      * @param values the meta data to add
      * @see setMetaData()
@@ -185,7 +177,7 @@ public:
     void addMetaData(const QMap<QString, QString> &values);
 
     /**
-     * Add key/value pairs to the meta data that is sent to the slave.
+     * Add key/value pairs to the meta data that is sent to the worker.
      * If a certain key already existed, it will remain unchanged.
      * @param values the meta data to merge
      * @see setMetaData()
@@ -199,15 +191,15 @@ public:
     MetaData outgoingMetaData() const;
 
     /**
-     * Get meta data received from the slave.
-     * (Valid when first data is received and/or slave is finished)
+     * Get meta data received from the worker.
+     * (Valid when first data is received and/or worker is finished)
      * @return the job's meta data
      */
     MetaData metaData() const;
 
     /**
-     * Query meta data received from the slave.
-     * (Valid when first data is received and/or slave is finished)
+     * Query meta data received from the worker.
+     * (Valid when first data is received and/or worker is finished)
      * @param key the key of the meta data to retrieve
      * @return the value of the meta data, or QString() if the
      *         @p key does not exist
@@ -215,22 +207,22 @@ public:
     QString queryMetaData(const QString &key);
 
 protected:
-
 Q_SIGNALS:
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
-     * @deprecated. Don't use !
      * Emitted when the job is canceled.
      * Signal result() is emitted as well, and error() is,
      * in this case, ERR_USER_CANCELED.
      * @param job the job that emitted this signal
+     * @deprecated Since 5.0. Don't use !
      */
-#ifndef KIOCORE_NO_DEPRECATED
-    KIOCORE_DEPRECATED void canceled(KJob *job);
+    KIOCORE_DEPRECATED_VERSION(5, 0, "Do not use")
+    void canceled(KJob *job);
 #endif
 
     /**
-     * Emitted when the slave successfully connected to the host.
-     * There is no guarantee the slave will send this, and this is
+     * Emitted when the worker successfully connected to the host.
+     * There is no guarantee the worker will send this, and this is
      * currently unused (in the applications).
      * @param job the job that emitted this signal
      */
@@ -240,7 +232,7 @@ protected:
     /**
      * Add a job that has to be finished before a result
      * is emitted. This has obviously to be called before
-     * the finish signal is emitted by the slave.
+     * the finish signal is emitted by the worker.
      *
      * @param job the subjob to add
      */
@@ -261,13 +253,6 @@ protected:
     JobPrivate *const d_ptr;
 
 private:
-    /**
-     * Forward signal from subjob.
-     * @param job the subjob
-     * @param speed the speed in bytes/s
-     * @see speed()
-     */
-    Q_PRIVATE_SLOT(d_func(), void slotSpeed(KJob *job, unsigned long speed))
     Q_DECLARE_PRIVATE(Job)
 };
 
@@ -275,6 +260,7 @@ private:
  * Flags for the job properties.
  * Not all flags are supported in all cases. Please see documentation of
  * the calling function!
+ * @see JobFlags
  */
 enum JobFlag {
     /**
@@ -283,7 +269,7 @@ enum JobFlag {
     DefaultFlags = 0,
 
     /**
-     * Hide progress information dialog, i.e. don't show a GUI.
+     * Hide progress information dialog, i.e.\ don't show a GUI.
      */
     HideProgressInfo = 1,
 
@@ -304,7 +290,7 @@ enum JobFlag {
     Overwrite = 4,
 
     /**
-     * When set, notifies the slave that application/job does not want privilege execution.
+     * When set, notifies the worker that application/job does not want privilege execution.
      * So in case of failure due to insufficient privileges show an error without attempting
      * to run the operation as root first.
      *
@@ -312,6 +298,9 @@ enum JobFlag {
      */
     NoPrivilegeExecution = 8,
 };
+/**
+ * Stores a combination of #JobFlag values.
+ */
 Q_DECLARE_FLAGS(JobFlags, JobFlag)
 Q_DECLARE_OPERATORS_FOR_FLAGS(JobFlags)
 
