@@ -10,24 +10,24 @@
 
 #include "ktcpsocket.h" // TODO KF6 remove include
 
+#include <QDate>
 #include <QSslCertificate>
 #include <QSslError>
 #include <QString>
 #include <QStringList>
-#include <QDate>
+
+#include <memory>
 
 class QDBusArgument;
-class QSslCertificate;
 class KSslCertificateRulePrivate;
 class KSslCertificateManagerPrivate;
 
-//### document this... :/
+// ### document this... :/
 /** Certificate rule. */
 class KIOCORE_EXPORT KSslCertificateRule
 {
 public:
-    KSslCertificateRule(const QSslCertificate &cert = QSslCertificate(),
-                        const QString &hostName = QString());
+    KSslCertificateRule(const QSslCertificate &cert = QSslCertificate(), const QString &hostName = QString());
     KSslCertificateRule(const KSslCertificateRule &other);
     ~KSslCertificateRule();
     KSslCertificateRule &operator=(const KSslCertificateRule &other);
@@ -84,13 +84,14 @@ public:
      * @since 5.64
      */
     QList<QSslError> filterErrors(const QList<QSslError> &errors) const;
+
 private:
     friend QDBusArgument &operator<<(QDBusArgument &argument, const KSslCertificateRule &rule); // TODO KF6 remove
     friend class KSSLD; // TODO KF6 remove
-    KSslCertificateRulePrivate *const d;
+    std::unique_ptr<KSslCertificateRulePrivate> const d;
 };
 
-//### document this too... :/
+// ### document this too... :/
 /** Certificate manager. */
 class KIOCORE_EXPORT KSslCertificateManager
 {
@@ -132,7 +133,7 @@ private:
     KSslCertificateManager();
     ~KSslCertificateManager();
 
-    KSslCertificateManagerPrivate *const d;
+    std::unique_ptr<KSslCertificateManagerPrivate> d;
 };
 
 #endif
